@@ -1,4 +1,5 @@
-import ipaddress
+from ipaddress import IPv6Address
+from typing import str
 
 lookup_table = [
     "0",
@@ -89,23 +90,23 @@ lookup_table = [
 ]
 
 
-def encode(ipv6):
+def encode(ipv6: str) -> str:
     lst = [0] * 0o24
-    num_ipv6 = int(ipaddress.ip_address(ipv6))
+    num_ipv6 = int(IPv6Address(ipv6))
     idx = 0
     while num_ipv6 > 0:
         lst[idx] = num_ipv6 % 0x55
-        num_ipv6 = num_ipv6 // 0x55
-        idx = idx + 1
+        num_ipv6 /= 0x55
+        idx += 1
     return "".join(list(map(lambda x: lookup_table[x], list(reversed(lst)))))
 
 
-def decode(encoded_ipv6):
+def decode(encoded_ipv6: str) -> str:
     exp = 0o23
     sum = 0
     for elem in list(
         map(lambda x: lookup_table.index(x), ",".join(encoded_ipv6).split(","))
     ):
-        sum = sum + elem * 0x55 ** exp
-        exp = exp - 1
-    return ipaddress.IPv6Address(sum)
+        sum += elem * 0x55 ** exp
+        exp -= 1
+    return IPv6Address(sum)
